@@ -2,9 +2,11 @@ from .create_sql_query import CreateSqlQueryPayload
 from .sql_query import SqlQueryPayload
 from .sql_result_pagination import SqlResultPaginationPayload
 from .delete_statement import DeleteStatementPayload
+from .delete_file import DeleteFilesPayload
 
 
 __all__ = [
+    "DeleteFilesPayload",
     "CreateSqlQueryPayload",
     "SqlQueryPayload",
     "SqlResultPaginationPayload",
